# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
# Copyright 2013 Canonical
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.

"""RSS Reader app autopilot tests."""

from __future__ import absolute_import

from autopilot.matchers import Eventually
from testtools.matchers import Equals, NotEquals

from ubuntu_rssreader_app.tests import RssreaderTestCase
from time import sleep

class TestMainWindow(RssreaderTestCase):

    def setUp(self):
        super(TestMainWindow, self).setUp()
        self.assertThat(
            self.ubuntusdk.get_qml_view().visible, Eventually(Equals(True)))

    def tearDown(self):
        super(TestMainWindow, self).tearDown()

    def test_add_new_feed(self):
        event_view = self.ubuntusdk.get_qml_view()
        self.insert_canonical_feed()
        self.remove_canonical_feed(event_view)
        
    def test_view_feeds(self):
        event_view = self.ubuntusdk.get_qml_view()
        #add Canonical feed
        self.insert_canonical_feed()
        
        #-----> view all news:
        #click list all news list item
        list_all_news = self.main_window.get_list_all_news()
        #does it exist?
        self.assertThat(list_all_news, NotEquals(None))
        #let's click it
        self.mouse.move_to_object(list_all_news)
        self.mouse.click()            
        #verify list all news page is open
        lambda: self.assertThat(event_view, Eventually(Equals("ArticleListPage.qml")))
        self.click_back_Toolbar_Button()
   
        #-----> view individual feed:
        event_view = self.ubuntusdk.get_qml_view()        
        #click Canonical feed item
        canonical_feed = self.main_window.get_canonical_feed()
        #does it exist?
        lambda: self.assertThat(canonical_feed, NotEquals(None))
        #let's click it
        self.mouse.move_to_object(canonical_feed)
        self.mouse.click()
        #verify list all news page is open
        lambda: self.assertThat(event_view, Eventually(Equals("ArticleListPage.qml")))
        self.click_back_Toolbar_Button()
        
        self.remove_canonical_feed(event_view)
        
    def insert_canonical_feed(self):
        #toggle toolbar
        self.ubuntusdk.toggle_toolbar()
        #click on add feed button
        self.ubuntusdk.click_toolbar_button('Add feed')
        #type feed in input field
        new_Feed_Url = self.main_window.get_new_event_name_input_box()
        self.pointing_device.click_object(new_Feed_Url)
        self.keyboard.type("http://www.canonical.com/rss.xml")
        #click confirm button to save RSS
        confirm_btn = self.main_window.get_confirm_button()
        #does it exist?
        self.assertThat(confirm_btn, NotEquals(None))
        #let's click it
        self.mouse.move_to_object(confirm_btn)
        self.mouse.click()
        #verify Feed list page is open
        lambda: self.assertThat(event_view, Eventually(Equals("FeedListPage.qml")))
        #check that feed is updated, not empty
        canonical_feed_before = self.main_window.get_individual_feed().text
        self.assertThat(canonical_feed_before, Eventually(Equals("http://www.canonical.com/rss.xml")))
        #had to put this sleep here otherwise test fails
        sleep(2)
        self.assertThat(canonical_feed_before, NotEquals(self.main_window.get_individual_feed().text))
        #verify feed has been added
        canonical_feed = self.main_window.get_individual_feed().text
        self.assertThat(canonical_feed, Equals("Canonical"))
                
    def remove_canonical_feed(self,event_view):
        canonical_feed = self.main_window.get_canonical_feed()
        #does it exist?
        self.assertThat(canonical_feed, NotEquals(None))
        #verify list all news page is open
        lambda: self.assertThat(event_view, Eventually(Equals("ArticleListPage.qml")))
        #let's click it
        self.mouse.move_to_object(canonical_feed)
        self.mouse.click_object(canonical_feed, button=1, press_duration=4)
        #select remove feed from popover context menu
        remove_in_context_menu = self.main_window.get_remove_form_popOver()
        #let's click it
        self.mouse.move_to_object(remove_in_context_menu)
        self.mouse.click()
        self.assertThat(self.main_window.get_canonical_feed, Eventually(Equals(None), timeout=30))
     
    def click_back_Toolbar_Button(self):
        #toggle toolbar
        self.ubuntusdk.toggle_toolbar()
        #click on back button
        backTBButton = self.app.select_single('Button', text='Back')
        #let's click it
        self.mouse.move_to_object(backTBButton)
        self.mouse.click()